@@ -1,7 +1,11 @@
 from .connection import RedisConnection, create_connection
-from .commands import Redis, create_redis, create_reconnecting_redis
+from .commands import (
+    Redis, create_redis,
+    create_reconnecting_redis,
+    GeoPoint, GeoMember,
+    )
 from .pool import RedisPool, create_pool
-from .util import Channel
+from .pubsub import Channel
 from .errors import (
     ConnectionClosedError,
     MultiExecError,
@@ -15,7 +19,7 @@ from .errors import (
     )
 
 
-__version__ = '0.2.9'
+__version__ = '0.3.0'
 
 # make pyflakes happy
 (create_connection, RedisConnection,
@@ -25,4 +29,5 @@ __version__ = '0.2.9'
  PipelineError, MultiExecError, ConnectionClosedError,
  ChannelClosedError, WatchVariableError,
  PoolClosedError,
+ GeoPoint, GeoMember,
  )
