@@ -14,8 +14,13 @@ from .scripting import ScriptingCommandsMixin
 from .server import ServerCommandsMixin
 from .pubsub import PubSubCommandsMixin
 from .cluster import ClusterCommandsMixin
+from .geo import GeoCommandsMixin, GeoPoint, GeoMember
 
-__all__ = ['create_redis', 'Redis', 'Pipeline', 'MultiExec']
+__all__ = [
+    'create_redis', 'Redis',
+    'Pipeline', 'MultiExec',
+    'GeoPoint', 'GeoMember',
+]
 
 
 class AutoConnector(object):
@@ -52,7 +57,8 @@ class Redis(GenericCommandsMixin, StringCommandsMixin,
             HashCommandsMixin, TransactionsCommandsMixin,
             SortedSetCommandsMixin, ListCommandsMixin,
             ScriptingCommandsMixin, ServerCommandsMixin,
-            PubSubCommandsMixin, ClusterCommandsMixin):
+            PubSubCommandsMixin, ClusterCommandsMixin,
+            GeoCommandsMixin):
     """High-level Redis interface.
 
     Gathers in one place Redis commands implemented in mixins.
