@@ -69,24 +69,24 @@ class HashCommandsMixin:
 
         dict can be passed as first positional argument:
 
-        >>> yield from redis.hmset_dict(
+        >>> await redis.hmset_dict(
         ...     'key', {'field1': 'value1', 'field2': 'value2'})
 
         or keyword arguments can be used:
 
-        >>> yield from redis.hmset_dict(
+        >>> await redis.hmset_dict(
         ...     'key', field1='value1', field2='value2')
 
         or dict argument can be mixed with kwargs:
 
-        >>> yield from redis.hmset_dict(
+        >>> await redis.hmset_dict(
         ...     'key', {'field1': 'value1'}, field2='value2')
 
         .. note:: ``dict`` and ``kwargs`` not get mixed into single dictionary,
            if both specified and both have same key(s) -- ``kwargs`` will win:
 
-           >>> yield from redis.hmset_dict('key', {'foo': 'bar'}, foo='baz')
-           >>> yield from redis.hget('key', 'foo', encoding='utf-8')
+           >>> await redis.hmset_dict('key', {'foo': 'bar'}, foo='baz')
+           >>> await redis.hget('key', 'foo', encoding='utf-8')
            'baz'
 
         """
