@@ -112,9 +112,17 @@ class ServerCommandsMixin:
         fut = self._conn.execute('FLUSHDB')
         return wait_ok(fut)
 
-    def info(self, section):
-        """Get information and statistics about the server."""
-        # TODO: check section
+    def info(self, section='default'):
+        """Get information and statistics about the server.
+
+        If called without argument will return default set of sections.
+        For available sections, see http://redis.io/commands/INFO
+
+        :raises ValueError: if section is invalid
+
+        """
+        if not section:
+            raise ValueError("invalid section")
         fut = self._conn.execute(b'INFO', section, encoding='utf-8')
         return wait_convert(fut, parse_info)
 
@@ -211,8 +219,7 @@ def to_time(obj):
 
 
 def to_tuples(value):
-    lines = iter(value.splitlines(False))
-    line = next(lines)
+    line, *lines = value.splitlines(False)
     line = list(map(_split, line.split(' ')))
     ClientInfo = namedtuple('ClientInfo', ' '.join(k for k, v in line))
     # TODO: parse flags and other known fields
@@ -225,8 +232,8 @@ def to_tuples(value):
 def parse_info(info):
     res = {}
     for block in info.split('\r\n\r\n'):
-        block = iter(block.strip().splitlines())
-        section = next(block)[2:].lower()
+        section, *block = block.strip().splitlines()
+        section = section[2:].lower()
         res[section] = tmp = {}
         for line in block:
             key, value = line.split(':')
