@@ -4,6 +4,10 @@ __all__ = [
     'ReplyError',
     'PipelineError',
     'MultiExecError',
+    'WatchVariableError',
+    'ChannelClosedError',
+    'ConnectionClosedError',
+    'PoolClosedError',
     ]
 
 
@@ -30,8 +34,18 @@ class MultiExecError(PipelineError):
     """Raised if command within MULTI/EXEC block caused error."""
 
 
+class WatchVariableError(MultiExecError):
+    """Raised if watched variable changed (EXEC returns None)."""
+
+
 class ChannelClosedError(RedisError):
     """Raised when Pub/Sub channel is unsubscribed and messages queue is empty.
     """
 
-# TODO: add ConnectionClosed exception.
+
+class ConnectionClosedError(RedisError):
+    """Raised if connection to server was closed."""
+
+
+class PoolClosedError(RedisError):
+    """Raised if pool is closed."""
