@@ -130,7 +130,8 @@ def serverB(start_server):
 
 
 def pytest_addoption(parser):
-    parser.addoption('--redis-server', default='/usr/bin/redis-server',
+    parser.addoption('--redis-server', default=[],
+                     action="append",
                      help="Path to redis-server executable,"
                           " defaults to `%(default)s`")
     parser.addoption('--ssl-cafile', default='tests/ssl/test.crt',
@@ -140,8 +141,8 @@ def pytest_addoption(parser):
                      help="Run tests with uvloop")
 
 
-def _read_server_version(config):
-    args = [config.getoption('--redis-server'), '--version']
+def _read_server_version(redis_bin):
+    args = [redis_bin, '--version']
     with subprocess.Popen(args, stdout=subprocess.PIPE) as proc:
         version = proc.stdout.readline().decode('utf-8')
     for part in version.split():
@@ -153,7 +154,10 @@ def _read_server_version(config):
     return tuple(map(int, part[2:].split('.')))
 
 
-@pytest.yield_fixture(scope='session')
+REDIS_SERVERS = []
+
+
+@pytest.yield_fixture(scope='session', params=REDIS_SERVERS)
 def start_server(request, unused_port):
 
     TCPAddress = namedtuple('TCPAddress', 'host port')
@@ -162,7 +166,8 @@ def start_server(request, unused_port):
     processes = []
     servers = {}
 
-    version = _read_server_version(request.config)
+    version = _read_server_version(request.param)
+    verbose = request.config.getoption('-v') > 3
 
     def maker(name):
         if name in servers:
@@ -170,18 +175,28 @@ def start_server(request, unused_port):
 
         port = unused_port()
         tcp_address = TCPAddress('localhost', port)
-        unixsocket = '/tmp/redis.{}.sock'.format(port)
+        cmd = [request.param,
+               '--daemonize', 'no',
+               '--save', '""',
+               '--port', str(port),
+               ]
+        if sys.platform == 'win32':
+            unixsocket = None
+        else:
+            unixsocket = '/tmp/redis.{}.sock'.format(port)
+            cmd.extend(['--unixsocket', unixsocket])
 
-        proc = subprocess.Popen([request.config.getoption('--redis-server'),
-                                 '--daemonize', 'no',
-                                 '--save', '""',
-                                 '--port', str(port),
-                                 '--unixsocket', unixsocket,
-                                 ], stdout=subprocess.PIPE)
+        proc = subprocess.Popen(cmd,
+                                stdout=subprocess.PIPE,
+                                stderr=subprocess.STDOUT)
         processes.append(proc)
         log = b''
         while b'The server is now ready to accept connections ' not in log:
+            assert proc.poll() is None, (
+                "Process terminated", proc.returncode, proc.stdout.read())
             log = proc.stdout.readline()
+            if log and verbose:
+                print(log)
 
         info = RedisServer(name, tcp_address, unixsocket, version)
         servers.setdefault(name, info)
@@ -284,10 +299,17 @@ def pytest_ignore_collect(path, config):
 
 
 def pytest_collection_modifyitems(session, config, items):
-    version = _read_server_version(config)
+    versions = {srv: _read_server_version(srv)
+                for srv in REDIS_SERVERS}
+    assert versions, ("Expected to detect redis versions", REDIS_SERVERS)
     for item in items:
         if 'redis_version' in item.keywords:
             marker = item.keywords['redis_version']
+            kw = item.keywords
+            version = [v for k, v in versions.items()
+                       if k in kw or k.replace('\\', '\\\\') in kw]
+            assert version, ("No version found", versions, item.keywords)
+            version = version[0]
             if version < marker.kwargs['version']:
                 item.add_marker(pytest.mark.skip(
                     reason=marker.kwargs['reason']))
@@ -298,6 +320,8 @@ def pytest_collection_modifyitems(session, config, items):
 
 
 def pytest_configure(config):
+    bins = config.getoption('--redis-server')[:]
+    REDIS_SERVERS[:] = bins or ['/usr/bin/redis-server']
     if config.getoption('--uvloop'):
         try:
             import uvloop
